# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.rpc.status_pb2 import Status as google___rpc___status_pb2___Status
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.conversion_adjustment_type_pb2 import (
    ConversionAdjustmentTypeEnum as google___ads___googleads___v6___enums___conversion_adjustment_type_pb2___ConversionAdjustmentTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UploadConversionAdjustmentsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    partial_failure: builtin___bool = ...
    validate_only: builtin___bool = ...
    @property
    def conversion_adjustments(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___ConversionAdjustment
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        conversion_adjustments: typing___Optional[
            typing___Iterable[type___ConversionAdjustment]
        ] = None,
        partial_failure: typing___Optional[builtin___bool] = None,
        validate_only: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "conversion_adjustments",
            b"conversion_adjustments",
            "customer_id",
            b"customer_id",
            "partial_failure",
            b"partial_failure",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

type___UploadConversionAdjustmentsRequest = UploadConversionAdjustmentsRequest

class UploadConversionAdjustmentsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___ConversionAdjustmentResult
    ]: ...
    def __init__(
        self,
        *,
        partial_failure_error: typing___Optional[
            google___rpc___status_pb2___Status
        ] = None,
        results: typing___Optional[
            typing___Iterable[type___ConversionAdjustmentResult]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error", "results", b"results"
        ],
    ) -> None: ...

type___UploadConversionAdjustmentsResponse = UploadConversionAdjustmentsResponse

class ConversionAdjustment(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    conversion_action: typing___Text = ...
    adjustment_date_time: typing___Text = ...
    adjustment_type: google___ads___googleads___v6___enums___conversion_adjustment_type_pb2___ConversionAdjustmentTypeEnum.ConversionAdjustmentTypeValue = ...
    order_id: typing___Text = ...
    @property
    def restatement_value(self) -> type___RestatementValue: ...
    @property
    def gclid_date_time_pair(self) -> type___GclidDateTimePair: ...
    def __init__(
        self,
        *,
        conversion_action: typing___Optional[typing___Text] = None,
        adjustment_date_time: typing___Optional[typing___Text] = None,
        adjustment_type: typing___Optional[
            google___ads___googleads___v6___enums___conversion_adjustment_type_pb2___ConversionAdjustmentTypeEnum.ConversionAdjustmentTypeValue
        ] = None,
        restatement_value: typing___Optional[type___RestatementValue] = None,
        gclid_date_time_pair: typing___Optional[type___GclidDateTimePair] = None,
        order_id: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_adjustment_date_time",
            b"_adjustment_date_time",
            "_conversion_action",
            b"_conversion_action",
            "adjustment_date_time",
            b"adjustment_date_time",
            "conversion_action",
            b"conversion_action",
            "conversion_identifier",
            b"conversion_identifier",
            "gclid_date_time_pair",
            b"gclid_date_time_pair",
            "order_id",
            b"order_id",
            "restatement_value",
            b"restatement_value",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_adjustment_date_time",
            b"_adjustment_date_time",
            "_conversion_action",
            b"_conversion_action",
            "adjustment_date_time",
            b"adjustment_date_time",
            "adjustment_type",
            b"adjustment_type",
            "conversion_action",
            b"conversion_action",
            "conversion_identifier",
            b"conversion_identifier",
            "gclid_date_time_pair",
            b"gclid_date_time_pair",
            "order_id",
            b"order_id",
            "restatement_value",
            b"restatement_value",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_adjustment_date_time", b"_adjustment_date_time"
        ],
    ) -> typing_extensions___Literal["adjustment_date_time"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions___Literal["conversion_action"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "conversion_identifier", b"conversion_identifier"
        ],
    ) -> typing_extensions___Literal["gclid_date_time_pair", "order_id"]: ...

type___ConversionAdjustment = ConversionAdjustment

class RestatementValue(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    adjusted_value: builtin___float = ...
    currency_code: typing___Text = ...
    def __init__(
        self,
        *,
        adjusted_value: typing___Optional[builtin___float] = None,
        currency_code: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_adjusted_value",
            b"_adjusted_value",
            "_currency_code",
            b"_currency_code",
            "adjusted_value",
            b"adjusted_value",
            "currency_code",
            b"currency_code",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_adjusted_value",
            b"_adjusted_value",
            "_currency_code",
            b"_currency_code",
            "adjusted_value",
            b"adjusted_value",
            "currency_code",
            b"currency_code",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_adjusted_value", b"_adjusted_value"],
    ) -> typing_extensions___Literal["adjusted_value"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions___Literal["currency_code"]: ...

type___RestatementValue = RestatementValue

class GclidDateTimePair(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    gclid: typing___Text = ...
    conversion_date_time: typing___Text = ...
    def __init__(
        self,
        *,
        gclid: typing___Optional[typing___Text] = None,
        conversion_date_time: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_conversion_date_time",
            b"_conversion_date_time",
            "_gclid",
            b"_gclid",
            "conversion_date_time",
            b"conversion_date_time",
            "gclid",
            b"gclid",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_conversion_date_time",
            b"_conversion_date_time",
            "_gclid",
            b"_gclid",
            "conversion_date_time",
            b"conversion_date_time",
            "gclid",
            b"gclid",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_conversion_date_time", b"_conversion_date_time"
        ],
    ) -> typing_extensions___Literal["conversion_date_time"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_gclid", b"_gclid"]
    ) -> typing_extensions___Literal["gclid"]: ...

type___GclidDateTimePair = GclidDateTimePair

class ConversionAdjustmentResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    conversion_action: typing___Text = ...
    adjustment_date_time: typing___Text = ...
    adjustment_type: google___ads___googleads___v6___enums___conversion_adjustment_type_pb2___ConversionAdjustmentTypeEnum.ConversionAdjustmentTypeValue = ...
    order_id: typing___Text = ...
    @property
    def gclid_date_time_pair(self) -> type___GclidDateTimePair: ...
    def __init__(
        self,
        *,
        conversion_action: typing___Optional[typing___Text] = None,
        adjustment_date_time: typing___Optional[typing___Text] = None,
        adjustment_type: typing___Optional[
            google___ads___googleads___v6___enums___conversion_adjustment_type_pb2___ConversionAdjustmentTypeEnum.ConversionAdjustmentTypeValue
        ] = None,
        gclid_date_time_pair: typing___Optional[type___GclidDateTimePair] = None,
        order_id: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_adjustment_date_time",
            b"_adjustment_date_time",
            "_conversion_action",
            b"_conversion_action",
            "adjustment_date_time",
            b"adjustment_date_time",
            "conversion_action",
            b"conversion_action",
            "conversion_identifier",
            b"conversion_identifier",
            "gclid_date_time_pair",
            b"gclid_date_time_pair",
            "order_id",
            b"order_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_adjustment_date_time",
            b"_adjustment_date_time",
            "_conversion_action",
            b"_conversion_action",
            "adjustment_date_time",
            b"adjustment_date_time",
            "adjustment_type",
            b"adjustment_type",
            "conversion_action",
            b"conversion_action",
            "conversion_identifier",
            b"conversion_identifier",
            "gclid_date_time_pair",
            b"gclid_date_time_pair",
            "order_id",
            b"order_id",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_adjustment_date_time", b"_adjustment_date_time"
        ],
    ) -> typing_extensions___Literal["adjustment_date_time"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions___Literal["conversion_action"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "conversion_identifier", b"conversion_identifier"
        ],
    ) -> typing_extensions___Literal["gclid_date_time_pair", "order_id"]: ...

type___ConversionAdjustmentResult = ConversionAdjustmentResult



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SizeLimitErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    SizeLimitErrorValue = typing___NewType("SizeLimitErrorValue", builtin___int)
    type___SizeLimitErrorValue = SizeLimitErrorValue
    SizeLimitError: _SizeLimitError
    class _SizeLimitError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            SizeLimitErrorEnum.SizeLimitErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(SizeLimitErrorEnum.SizeLimitErrorValue, 0)
        UNKNOWN = typing___cast(SizeLimitErrorEnum.SizeLimitErrorValue, 1)
        REQUEST_SIZE_LIMIT_EXCEEDED = typing___cast(
            SizeLimitErrorEnum.SizeLimitErrorValue, 2
        )
        RESPONSE_SIZE_LIMIT_EXCEEDED = typing___cast(
            SizeLimitErrorEnum.SizeLimitErrorValue, 3
        )
    UNSPECIFIED = typing___cast(SizeLimitErrorEnum.SizeLimitErrorValue, 0)
    UNKNOWN = typing___cast(SizeLimitErrorEnum.SizeLimitErrorValue, 1)
    REQUEST_SIZE_LIMIT_EXCEEDED = typing___cast(
        SizeLimitErrorEnum.SizeLimitErrorValue, 2
    )
    RESPONSE_SIZE_LIMIT_EXCEEDED = typing___cast(
        SizeLimitErrorEnum.SizeLimitErrorValue, 3
    )
    type___SizeLimitError = SizeLimitError
    def __init__(self,) -> None: ...

type___SizeLimitErrorEnum = SizeLimitErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.enums.campaign_experiment_status_pb2 import (
    CampaignExperimentStatusEnum as google___ads___googleads___v3___enums___campaign_experiment_status_pb2___CampaignExperimentStatusEnum,
)
from google.ads.google_ads.v3.proto.enums.campaign_experiment_traffic_split_type_pb2 import (
    CampaignExperimentTrafficSplitTypeEnum as google___ads___googleads___v3___enums___campaign_experiment_traffic_split_type_pb2___CampaignExperimentTrafficSplitTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignExperiment(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    traffic_split_type: google___ads___googleads___v3___enums___campaign_experiment_traffic_split_type_pb2___CampaignExperimentTrafficSplitTypeEnum.CampaignExperimentTrafficSplitTypeValue = ...
    status: google___ads___googleads___v3___enums___campaign_experiment_status_pb2___CampaignExperimentStatusEnum.CampaignExperimentStatusValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def campaign_draft(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def description(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def traffic_split_percent(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def experiment_campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def long_running_operation(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def start_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def end_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        campaign_draft: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        description: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        traffic_split_percent: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        traffic_split_type: typing___Optional[
            google___ads___googleads___v3___enums___campaign_experiment_traffic_split_type_pb2___CampaignExperimentTrafficSplitTypeEnum.CampaignExperimentTrafficSplitTypeValue
        ] = None,
        experiment_campaign: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v3___enums___campaign_experiment_status_pb2___CampaignExperimentStatusEnum.CampaignExperimentStatusValue
        ] = None,
        long_running_operation: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        start_date: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        end_date: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "campaign_draft",
            b"campaign_draft",
            "description",
            b"description",
            "end_date",
            b"end_date",
            "experiment_campaign",
            b"experiment_campaign",
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
            "start_date",
            b"start_date",
            "traffic_split_percent",
            b"traffic_split_percent",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "campaign_draft",
            b"campaign_draft",
            "description",
            b"description",
            "end_date",
            b"end_date",
            "experiment_campaign",
            b"experiment_campaign",
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "start_date",
            b"start_date",
            "status",
            b"status",
            "traffic_split_percent",
            b"traffic_split_percent",
            "traffic_split_type",
            b"traffic_split_type",
        ],
    ) -> None: ...

type___CampaignExperiment = CampaignExperiment



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.billing_setup_status_pb2 import (
    BillingSetupStatusEnum as google___ads___googleads___v5___enums___billing_setup_status_pb2___BillingSetupStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.time_type_pb2 import (
    TimeTypeEnum as google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BillingSetup(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class PaymentsAccountInfo(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def payments_account_id(
            self,
        ) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def payments_account_name(
            self,
        ) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def payments_profile_id(
            self,
        ) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def payments_profile_name(
            self,
        ) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def secondary_payments_profile_id(
            self,
        ) -> google___protobuf___wrappers_pb2___StringValue: ...
        def __init__(
            self,
            *,
            payments_account_id: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            payments_account_name: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            payments_profile_id: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            payments_profile_name: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            secondary_payments_profile_id: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "payments_account_id",
                b"payments_account_id",
                "payments_account_name",
                b"payments_account_name",
                "payments_profile_id",
                b"payments_profile_id",
                "payments_profile_name",
                b"payments_profile_name",
                "secondary_payments_profile_id",
                b"secondary_payments_profile_id",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "payments_account_id",
                b"payments_account_id",
                "payments_account_name",
                b"payments_account_name",
                "payments_profile_id",
                b"payments_profile_id",
                "payments_profile_name",
                b"payments_profile_name",
                "secondary_payments_profile_id",
                b"secondary_payments_profile_id",
            ],
        ) -> None: ...
    type___PaymentsAccountInfo = PaymentsAccountInfo

    resource_name: typing___Text = ...
    status: google___ads___googleads___v5___enums___billing_setup_status_pb2___BillingSetupStatusEnum.BillingSetupStatusValue = ...
    start_time_type: google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue = ...
    end_time_type: google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def payments_account(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def payments_account_info(self) -> type___BillingSetup.PaymentsAccountInfo: ...
    @property
    def start_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def end_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        status: typing___Optional[
            google___ads___googleads___v5___enums___billing_setup_status_pb2___BillingSetupStatusEnum.BillingSetupStatusValue
        ] = None,
        payments_account: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        payments_account_info: typing___Optional[
            type___BillingSetup.PaymentsAccountInfo
        ] = None,
        start_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        start_time_type: typing___Optional[
            google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue
        ] = None,
        end_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        end_time_type: typing___Optional[
            google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "end_date_time",
            b"end_date_time",
            "end_time",
            b"end_time",
            "end_time_type",
            b"end_time_type",
            "id",
            b"id",
            "payments_account",
            b"payments_account",
            "payments_account_info",
            b"payments_account_info",
            "start_date_time",
            b"start_date_time",
            "start_time",
            b"start_time",
            "start_time_type",
            b"start_time_type",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "end_date_time",
            b"end_date_time",
            "end_time",
            b"end_time",
            "end_time_type",
            b"end_time_type",
            "id",
            b"id",
            "payments_account",
            b"payments_account",
            "payments_account_info",
            b"payments_account_info",
            "resource_name",
            b"resource_name",
            "start_date_time",
            b"start_date_time",
            "start_time",
            b"start_time",
            "start_time_type",
            b"start_time_type",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["end_time", b"end_time"]
    ) -> typing_extensions___Literal["end_date_time", "end_time_type"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["start_time", b"start_time"]
    ) -> typing_extensions___Literal["start_date_time", "start_time_type"]: ...

type___BillingSetup = BillingSetup



from typing import Any

class KeywordPlanIdeaServiceStub:
    GenerateKeywordIdeas: Any = ...
    def __init__(self, channel: Any) -> None: ...

class KeywordPlanIdeaServiceServicer:
    def GenerateKeywordIdeas(self, request: Any, context: Any) -> None: ...

def add_KeywordPlanIdeaServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PlacementTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PlacementTypeValue = typing___NewType("PlacementTypeValue", builtin___int)
    type___PlacementTypeValue = PlacementTypeValue
    PlacementType: _PlacementType
    class _PlacementType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PlacementTypeEnum.PlacementTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(PlacementTypeEnum.PlacementTypeValue, 0)
        UNKNOWN = typing___cast(PlacementTypeEnum.PlacementTypeValue, 1)
        WEBSITE = typing___cast(PlacementTypeEnum.PlacementTypeValue, 2)
        MOBILE_APP_CATEGORY = typing___cast(PlacementTypeEnum.PlacementTypeValue, 3)
        MOBILE_APPLICATION = typing___cast(PlacementTypeEnum.PlacementTypeValue, 4)
        YOUTUBE_VIDEO = typing___cast(PlacementTypeEnum.PlacementTypeValue, 5)
        YOUTUBE_CHANNEL = typing___cast(PlacementTypeEnum.PlacementTypeValue, 6)
    UNSPECIFIED = typing___cast(PlacementTypeEnum.PlacementTypeValue, 0)
    UNKNOWN = typing___cast(PlacementTypeEnum.PlacementTypeValue, 1)
    WEBSITE = typing___cast(PlacementTypeEnum.PlacementTypeValue, 2)
    MOBILE_APP_CATEGORY = typing___cast(PlacementTypeEnum.PlacementTypeValue, 3)
    MOBILE_APPLICATION = typing___cast(PlacementTypeEnum.PlacementTypeValue, 4)
    YOUTUBE_VIDEO = typing___cast(PlacementTypeEnum.PlacementTypeValue, 5)
    YOUTUBE_CHANNEL = typing___cast(PlacementTypeEnum.PlacementTypeValue, 6)
    type___PlacementType = PlacementType
    def __init__(self,) -> None: ...

type___PlacementTypeEnum = PlacementTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ExternalConversionSourceEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ExternalConversionSourceValue = typing___NewType(
        "ExternalConversionSourceValue", builtin___int
    )
    type___ExternalConversionSourceValue = ExternalConversionSourceValue
    ExternalConversionSource: _ExternalConversionSource
    class _ExternalConversionSource(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ExternalConversionSourceEnum.ExternalConversionSourceValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 0
        )
        UNKNOWN = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 1
        )
        WEBPAGE = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 2
        )
        ANALYTICS = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 3
        )
        UPLOAD = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 4
        )
        AD_CALL_METRICS = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 5
        )
        WEBSITE_CALL_METRICS = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 6
        )
        STORE_VISITS = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 7
        )
        ANDROID_IN_APP = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 8
        )
        IOS_IN_APP = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 9
        )
        IOS_FIRST_OPEN = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 10
        )
        APP_UNSPECIFIED = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 11
        )
        ANDROID_FIRST_OPEN = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 12
        )
        UPLOAD_CALLS = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 13
        )
        FIREBASE = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 14
        )
        CLICK_TO_CALL = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 15
        )
        SALESFORCE = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 16
        )
        STORE_SALES_CRM = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 17
        )
        STORE_SALES_PAYMENT_NETWORK = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 18
        )
        GOOGLE_PLAY = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 19
        )
        THIRD_PARTY_APP_ANALYTICS = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 20
        )
        GOOGLE_ATTRIBUTION = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 21
        )
        STORE_SALES_DIRECT_UPLOAD = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 23
        )
        STORE_SALES = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 24
        )
        SEARCH_ADS_360 = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 25
        )
        GOOGLE_HOSTED = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 27
        )
        FLOODLIGHT = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 29
        )
        ANALYTICS_SEARCH_ADS_360 = typing___cast(
            ExternalConversionSourceEnum.ExternalConversionSourceValue, 31
        )
    UNSPECIFIED = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 0
    )
    UNKNOWN = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 1
    )
    WEBPAGE = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 2
    )
    ANALYTICS = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 3
    )
    UPLOAD = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 4
    )
    AD_CALL_METRICS = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 5
    )
    WEBSITE_CALL_METRICS = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 6
    )
    STORE_VISITS = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 7
    )
    ANDROID_IN_APP = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 8
    )
    IOS_IN_APP = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 9
    )
    IOS_FIRST_OPEN = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 10
    )
    APP_UNSPECIFIED = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 11
    )
    ANDROID_FIRST_OPEN = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 12
    )
    UPLOAD_CALLS = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 13
    )
    FIREBASE = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 14
    )
    CLICK_TO_CALL = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 15
    )
    SALESFORCE = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 16
    )
    STORE_SALES_CRM = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 17
    )
    STORE_SALES_PAYMENT_NETWORK = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 18
    )
    GOOGLE_PLAY = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 19
    )
    THIRD_PARTY_APP_ANALYTICS = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 20
    )
    GOOGLE_ATTRIBUTION = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 21
    )
    STORE_SALES_DIRECT_UPLOAD = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 23
    )
    STORE_SALES = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 24
    )
    SEARCH_ADS_360 = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 25
    )
    GOOGLE_HOSTED = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 27
    )
    FLOODLIGHT = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 29
    )
    ANALYTICS_SEARCH_ADS_360 = typing___cast(
        ExternalConversionSourceEnum.ExternalConversionSourceValue, 31
    )
    type___ExternalConversionSource = ExternalConversionSource
    def __init__(self,) -> None: ...

type___ExternalConversionSourceEnum = ExternalConversionSourceEnum



from typing import Any

class AdGroupAdServiceStub:
    GetAdGroupAd: Any = ...
    MutateAdGroupAds: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupAdServiceServicer:
    def GetAdGroupAd(self, request: Any, context: Any) -> None: ...
    def MutateAdGroupAds(self, request: Any, context: Any) -> None: ...

def add_AdGroupAdServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignCriterionErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignCriterionErrorValue = typing___NewType(
        "CampaignCriterionErrorValue", builtin___int
    )
    type___CampaignCriterionErrorValue = CampaignCriterionErrorValue
    CampaignCriterionError: _CampaignCriterionError
    class _CampaignCriterionError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignCriterionErrorEnum.CampaignCriterionErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 0
        )
        UNKNOWN = typing___cast(
            CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 1
        )
        CONCRETE_TYPE_REQUIRED = typing___cast(
            CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 2
        )
        INVALID_PLACEMENT_URL = typing___cast(
            CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 3
        )
        CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(
            CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 4
        )
        CANNOT_SET_STATUS_FOR_CRITERIA_TYPE = typing___cast(
            CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 5
        )
        CANNOT_SET_STATUS_FOR_EXCLUDED_CRITERIA = typing___cast(
            CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 6
        )
        CANNOT_TARGET_AND_EXCLUDE = typing___cast(
            CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 7
        )
        TOO_MANY_OPERATIONS = typing___cast(
            CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 8
        )
        OPERATOR_NOT_SUPPORTED_FOR_CRITERION_TYPE = typing___cast(
            CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 9
        )
        SHOPPING_CAMPAIGN_SALES_COUNTRY_NOT_SUPPORTED_FOR_SALES_CHANNEL = typing___cast(
            CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 10
        )
        CANNOT_ADD_EXISTING_FIELD = typing___cast(
            CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 11
        )
        CANNOT_UPDATE_NEGATIVE_CRITERION = typing___cast(
            CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 12
        )
    UNSPECIFIED = typing___cast(
        CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 0
    )
    UNKNOWN = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 1)
    CONCRETE_TYPE_REQUIRED = typing___cast(
        CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 2
    )
    INVALID_PLACEMENT_URL = typing___cast(
        CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 3
    )
    CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(
        CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 4
    )
    CANNOT_SET_STATUS_FOR_CRITERIA_TYPE = typing___cast(
        CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 5
    )
    CANNOT_SET_STATUS_FOR_EXCLUDED_CRITERIA = typing___cast(
        CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 6
    )
    CANNOT_TARGET_AND_EXCLUDE = typing___cast(
        CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 7
    )
    TOO_MANY_OPERATIONS = typing___cast(
        CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 8
    )
    OPERATOR_NOT_SUPPORTED_FOR_CRITERION_TYPE = typing___cast(
        CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 9
    )
    SHOPPING_CAMPAIGN_SALES_COUNTRY_NOT_SUPPORTED_FOR_SALES_CHANNEL = typing___cast(
        CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 10
    )
    CANNOT_ADD_EXISTING_FIELD = typing___cast(
        CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 11
    )
    CANNOT_UPDATE_NEGATIVE_CRITERION = typing___cast(
        CampaignCriterionErrorEnum.CampaignCriterionErrorValue, 12
    )
    type___CampaignCriterionError = CampaignCriterionError
    def __init__(self,) -> None: ...

type___CampaignCriterionErrorEnum = CampaignCriterionErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.common.tag_snippet_pb2 import (
    TagSnippet as google___ads___googleads___v3___common___tag_snippet_pb2___TagSnippet,
)
from google.ads.google_ads.v3.proto.enums.attribution_model_pb2 import (
    AttributionModelEnum as google___ads___googleads___v3___enums___attribution_model_pb2___AttributionModelEnum,
)
from google.ads.google_ads.v3.proto.enums.conversion_action_category_pb2 import (
    ConversionActionCategoryEnum as google___ads___googleads___v3___enums___conversion_action_category_pb2___ConversionActionCategoryEnum,
)
from google.ads.google_ads.v3.proto.enums.conversion_action_counting_type_pb2 import (
    ConversionActionCountingTypeEnum as google___ads___googleads___v3___enums___conversion_action_counting_type_pb2___ConversionActionCountingTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.conversion_action_status_pb2 import (
    ConversionActionStatusEnum as google___ads___googleads___v3___enums___conversion_action_status_pb2___ConversionActionStatusEnum,
)
from google.ads.google_ads.v3.proto.enums.conversion_action_type_pb2 import (
    ConversionActionTypeEnum as google___ads___googleads___v3___enums___conversion_action_type_pb2___ConversionActionTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.data_driven_model_status_pb2 import (
    DataDrivenModelStatusEnum as google___ads___googleads___v3___enums___data_driven_model_status_pb2___DataDrivenModelStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ConversionAction(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AttributionModelSettings(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        attribution_model: google___ads___googleads___v3___enums___attribution_model_pb2___AttributionModelEnum.AttributionModelValue = ...
        data_driven_model_status: google___ads___googleads___v3___enums___data_driven_model_status_pb2___DataDrivenModelStatusEnum.DataDrivenModelStatusValue = ...
        def __init__(
            self,
            *,
            attribution_model: typing___Optional[
                google___ads___googleads___v3___enums___attribution_model_pb2___AttributionModelEnum.AttributionModelValue
            ] = None,
            data_driven_model_status: typing___Optional[
                google___ads___googleads___v3___enums___data_driven_model_status_pb2___DataDrivenModelStatusEnum.DataDrivenModelStatusValue
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "attribution_model",
                b"attribution_model",
                "data_driven_model_status",
                b"data_driven_model_status",
            ],
        ) -> None: ...
    type___AttributionModelSettings = AttributionModelSettings
    class ValueSettings(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def default_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
        @property
        def default_currency_code(
            self,
        ) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def always_use_default_value(
            self,
        ) -> google___protobuf___wrappers_pb2___BoolValue: ...
        def __init__(
            self,
            *,
            default_value: typing___Optional[
                google___protobuf___wrappers_pb2___DoubleValue
            ] = None,
            default_currency_code: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            always_use_default_value: typing___Optional[
                google___protobuf___wrappers_pb2___BoolValue
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "always_use_default_value",
                b"always_use_default_value",
                "default_currency_code",
                b"default_currency_code",
                "default_value",
                b"default_value",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "always_use_default_value",
                b"always_use_default_value",
                "default_currency_code",
                b"default_currency_code",
                "default_value",
                b"default_value",
            ],
        ) -> None: ...
    type___ValueSettings = ValueSettings

    resource_name: typing___Text = ...
    status: google___ads___googleads___v3___enums___conversion_action_status_pb2___ConversionActionStatusEnum.ConversionActionStatusValue = ...
    type: google___ads___googleads___v3___enums___conversion_action_type_pb2___ConversionActionTypeEnum.ConversionActionTypeValue = ...
    category: google___ads___googleads___v3___enums___conversion_action_category_pb2___ConversionActionCategoryEnum.ConversionActionCategoryValue = ...
    counting_type: google___ads___googleads___v3___enums___conversion_action_counting_type_pb2___ConversionActionCountingTypeEnum.ConversionActionCountingTypeValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def owner_customer(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def include_in_conversions_metric(
        self,
    ) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def click_through_lookback_window_days(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def view_through_lookback_window_days(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def value_settings(self) -> type___ConversionAction.ValueSettings: ...
    @property
    def attribution_model_settings(
        self,
    ) -> type___ConversionAction.AttributionModelSettings: ...
    @property
    def tag_snippets(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v3___common___tag_snippet_pb2___TagSnippet
    ]: ...
    @property
    def phone_call_duration_seconds(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def app_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        status: typing___Optional[
            google___ads___googleads___v3___enums___conversion_action_status_pb2___ConversionActionStatusEnum.ConversionActionStatusValue
        ] = None,
        type: typing___Optional[
            google___ads___googleads___v3___enums___conversion_action_type_pb2___ConversionActionTypeEnum.ConversionActionTypeValue
        ] = None,
        category: typing___Optional[
            google___ads___googleads___v3___enums___conversion_action_category_pb2___ConversionActionCategoryEnum.ConversionActionCategoryValue
        ] = None,
        owner_customer: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        include_in_conversions_metric: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        click_through_lookback_window_days: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        view_through_lookback_window_days: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        value_settings: typing___Optional[type___ConversionAction.ValueSettings] = None,
        counting_type: typing___Optional[
            google___ads___googleads___v3___enums___conversion_action_counting_type_pb2___ConversionActionCountingTypeEnum.ConversionActionCountingTypeValue
        ] = None,
        attribution_model_settings: typing___Optional[
            type___ConversionAction.AttributionModelSettings
        ] = None,
        tag_snippets: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___common___tag_snippet_pb2___TagSnippet
            ]
        ] = None,
        phone_call_duration_seconds: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        app_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "app_id",
            b"app_id",
            "attribution_model_settings",
            b"attribution_model_settings",
            "click_through_lookback_window_days",
            b"click_through_lookback_window_days",
            "id",
            b"id",
            "include_in_conversions_metric",
            b"include_in_conversions_metric",
            "name",
            b"name",
            "owner_customer",
            b"owner_customer",
            "phone_call_duration_seconds",
            b"phone_call_duration_seconds",
            "value_settings",
            b"value_settings",
            "view_through_lookback_window_days",
            b"view_through_lookback_window_days",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "app_id",
            b"app_id",
            "attribution_model_settings",
            b"attribution_model_settings",
            "category",
            b"category",
            "click_through_lookback_window_days",
            b"click_through_lookback_window_days",
            "counting_type",
            b"counting_type",
            "id",
            b"id",
            "include_in_conversions_metric",
            b"include_in_conversions_metric",
            "name",
            b"name",
            "owner_customer",
            b"owner_customer",
            "phone_call_duration_seconds",
            b"phone_call_duration_seconds",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "tag_snippets",
            b"tag_snippets",
            "type",
            b"type",
            "value_settings",
            b"value_settings",
            "view_through_lookback_window_days",
            b"view_through_lookback_window_days",
        ],
    ) -> None: ...

type___ConversionAction = ConversionAction



from typing import Any

class KeywordPlanAdGroupServiceStub:
    GetKeywordPlanAdGroup: Any = ...
    MutateKeywordPlanAdGroups: Any = ...
    def __init__(self, channel: Any) -> None: ...

class KeywordPlanAdGroupServiceServicer:
    def GetKeywordPlanAdGroup(self, request: Any, context: Any) -> None: ...
    def MutateKeywordPlanAdGroups(self, request: Any, context: Any) -> None: ...

def add_KeywordPlanAdGroupServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.ad_type_infos_pb2 import (
    AppAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___AppAdInfo,
    AppEngagementAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___AppEngagementAdInfo,
    CallOnlyAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___CallOnlyAdInfo,
    DisplayUploadAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___DisplayUploadAdInfo,
    ExpandedDynamicSearchAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ExpandedDynamicSearchAdInfo,
    ExpandedTextAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ExpandedTextAdInfo,
    GmailAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___GmailAdInfo,
    HotelAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___HotelAdInfo,
    ImageAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ImageAdInfo,
    LegacyAppInstallAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___LegacyAppInstallAdInfo,
    LegacyResponsiveDisplayAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___LegacyResponsiveDisplayAdInfo,
    LocalAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___LocalAdInfo,
    ResponsiveDisplayAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ResponsiveDisplayAdInfo,
    ResponsiveSearchAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ResponsiveSearchAdInfo,
    ShoppingComparisonListingAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingComparisonListingAdInfo,
    ShoppingProductAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingProductAdInfo,
    ShoppingSmartAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingSmartAdInfo,
    TextAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___TextAdInfo,
    VideoAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___VideoAdInfo,
    VideoResponsiveAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___VideoResponsiveAdInfo,
)
from google.ads.google_ads.v6.proto.common.custom_parameter_pb2 import (
    CustomParameter as google___ads___googleads___v6___common___custom_parameter_pb2___CustomParameter,
)
from google.ads.google_ads.v6.proto.common.final_app_url_pb2 import (
    FinalAppUrl as google___ads___googleads___v6___common___final_app_url_pb2___FinalAppUrl,
)
from google.ads.google_ads.v6.proto.common.url_collection_pb2 import (
    UrlCollection as google___ads___googleads___v6___common___url_collection_pb2___UrlCollection,
)
from google.ads.google_ads.v6.proto.enums.ad_type_pb2 import (
    AdTypeEnum as google___ads___googleads___v6___enums___ad_type_pb2___AdTypeEnum,
)
from google.ads.google_ads.v6.proto.enums.device_pb2 import (
    DeviceEnum as google___ads___googleads___v6___enums___device_pb2___DeviceEnum,
)
from google.ads.google_ads.v6.proto.enums.system_managed_entity_source_pb2 import (
    SystemManagedResourceSourceEnum as google___ads___googleads___v6___enums___system_managed_entity_source_pb2___SystemManagedResourceSourceEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Ad(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    id: builtin___int = ...
    final_urls: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    final_mobile_urls: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    tracking_url_template: typing___Text = ...
    final_url_suffix: typing___Text = ...
    display_url: typing___Text = ...
    type: google___ads___googleads___v6___enums___ad_type_pb2___AdTypeEnum.AdTypeValue = ...
    added_by_google_ads: builtin___bool = ...
    device_preference: google___ads___googleads___v6___enums___device_pb2___DeviceEnum.DeviceValue = ...
    name: typing___Text = ...
    system_managed_resource_source: google___ads___googleads___v6___enums___system_managed_entity_source_pb2___SystemManagedResourceSourceEnum.SystemManagedResourceSourceValue = ...
    @property
    def final_app_urls(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___final_app_url_pb2___FinalAppUrl
    ]: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___custom_parameter_pb2___CustomParameter
    ]: ...
    @property
    def url_collections(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___url_collection_pb2___UrlCollection
    ]: ...
    @property
    def text_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___TextAdInfo: ...
    @property
    def expanded_text_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ExpandedTextAdInfo: ...
    @property
    def call_only_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___CallOnlyAdInfo: ...
    @property
    def expanded_dynamic_search_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ExpandedDynamicSearchAdInfo: ...
    @property
    def hotel_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___HotelAdInfo: ...
    @property
    def shopping_smart_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingSmartAdInfo: ...
    @property
    def shopping_product_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingProductAdInfo: ...
    @property
    def gmail_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___GmailAdInfo: ...
    @property
    def image_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ImageAdInfo: ...
    @property
    def video_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___VideoAdInfo: ...
    @property
    def video_responsive_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___VideoResponsiveAdInfo: ...
    @property
    def responsive_search_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ResponsiveSearchAdInfo: ...
    @property
    def legacy_responsive_display_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___LegacyResponsiveDisplayAdInfo: ...
    @property
    def app_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___AppAdInfo: ...
    @property
    def legacy_app_install_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___LegacyAppInstallAdInfo: ...
    @property
    def responsive_display_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ResponsiveDisplayAdInfo: ...
    @property
    def local_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___LocalAdInfo: ...
    @property
    def display_upload_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___DisplayUploadAdInfo: ...
    @property
    def app_engagement_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___AppEngagementAdInfo: ...
    @property
    def shopping_comparison_listing_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingComparisonListingAdInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        final_urls: typing___Optional[typing___Iterable[typing___Text]] = None,
        final_app_urls: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___final_app_url_pb2___FinalAppUrl
            ]
        ] = None,
        final_mobile_urls: typing___Optional[typing___Iterable[typing___Text]] = None,
        tracking_url_template: typing___Optional[typing___Text] = None,
        final_url_suffix: typing___Optional[typing___Text] = None,
        url_custom_parameters: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___custom_parameter_pb2___CustomParameter
            ]
        ] = None,
        display_url: typing___Optional[typing___Text] = None,
        type: typing___Optional[
            google___ads___googleads___v6___enums___ad_type_pb2___AdTypeEnum.AdTypeValue
        ] = None,
        added_by_google_ads: typing___Optional[builtin___bool] = None,
        device_preference: typing___Optional[
            google___ads___googleads___v6___enums___device_pb2___DeviceEnum.DeviceValue
        ] = None,
        url_collections: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___url_collection_pb2___UrlCollection
            ]
        ] = None,
        name: typing___Optional[typing___Text] = None,
        system_managed_resource_source: typing___Optional[
            google___ads___googleads___v6___enums___system_managed_entity_source_pb2___SystemManagedResourceSourceEnum.SystemManagedResourceSourceValue
        ] = None,
        text_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___TextAdInfo
        ] = None,
        expanded_text_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ExpandedTextAdInfo
        ] = None,
        call_only_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___CallOnlyAdInfo
        ] = None,
        expanded_dynamic_search_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ExpandedDynamicSearchAdInfo
        ] = None,
        hotel_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___HotelAdInfo
        ] = None,
        shopping_smart_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingSmartAdInfo
        ] = None,
        shopping_product_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingProductAdInfo
        ] = None,
        gmail_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___GmailAdInfo
        ] = None,
        image_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ImageAdInfo
        ] = None,
        video_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___VideoAdInfo
        ] = None,
        video_responsive_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___VideoResponsiveAdInfo
        ] = None,
        responsive_search_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ResponsiveSearchAdInfo
        ] = None,
        legacy_responsive_display_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___LegacyResponsiveDisplayAdInfo
        ] = None,
        app_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___AppAdInfo
        ] = None,
        legacy_app_install_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___LegacyAppInstallAdInfo
        ] = None,
        responsive_display_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ResponsiveDisplayAdInfo
        ] = None,
        local_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___LocalAdInfo
        ] = None,
        display_upload_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___DisplayUploadAdInfo
        ] = None,
        app_engagement_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___AppEngagementAdInfo
        ] = None,
        shopping_comparison_listing_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingComparisonListingAdInfo
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_added_by_google_ads",
            b"_added_by_google_ads",
            "_display_url",
            b"_display_url",
            "_final_url_suffix",
            b"_final_url_suffix",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_tracking_url_template",
            b"_tracking_url_template",
            "ad_data",
            b"ad_data",
            "added_by_google_ads",
            b"added_by_google_ads",
            "app_ad",
            b"app_ad",
            "app_engagement_ad",
            b"app_engagement_ad",
            "call_only_ad",
            b"call_only_ad",
            "display_upload_ad",
            b"display_upload_ad",
            "display_url",
            b"display_url",
            "expanded_dynamic_search_ad",
            b"expanded_dynamic_search_ad",
            "expanded_text_ad",
            b"expanded_text_ad",
            "final_url_suffix",
            b"final_url_suffix",
            "gmail_ad",
            b"gmail_ad",
            "hotel_ad",
            b"hotel_ad",
            "id",
            b"id",
            "image_ad",
            b"image_ad",
            "legacy_app_install_ad",
            b"legacy_app_install_ad",
            "legacy_responsive_display_ad",
            b"legacy_responsive_display_ad",
            "local_ad",
            b"local_ad",
            "name",
            b"name",
            "responsive_display_ad",
            b"responsive_display_ad",
            "responsive_search_ad",
            b"responsive_search_ad",
            "shopping_comparison_listing_ad",
            b"shopping_comparison_listing_ad",
            "shopping_product_ad",
            b"shopping_product_ad",
            "shopping_smart_ad",
            b"shopping_smart_ad",
            "text_ad",
            b"text_ad",
            "tracking_url_template",
            b"tracking_url_template",
            "video_ad",
            b"video_ad",
            "video_responsive_ad",
            b"video_responsive_ad",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_added_by_google_ads",
            b"_added_by_google_ads",
            "_display_url",
            b"_display_url",
            "_final_url_suffix",
            b"_final_url_suffix",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_tracking_url_template",
            b"_tracking_url_template",
            "ad_data",
            b"ad_data",
            "added_by_google_ads",
            b"added_by_google_ads",
            "app_ad",
            b"app_ad",
            "app_engagement_ad",
            b"app_engagement_ad",
            "call_only_ad",
            b"call_only_ad",
            "device_preference",
            b"device_preference",
            "display_upload_ad",
            b"display_upload_ad",
            "display_url",
            b"display_url",
            "expanded_dynamic_search_ad",
            b"expanded_dynamic_search_ad",
            "expanded_text_ad",
            b"expanded_text_ad",
            "final_app_urls",
            b"final_app_urls",
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_url_suffix",
            b"final_url_suffix",
            "final_urls",
            b"final_urls",
            "gmail_ad",
            b"gmail_ad",
            "hotel_ad",
            b"hotel_ad",
            "id",
            b"id",
            "image_ad",
            b"image_ad",
            "legacy_app_install_ad",
            b"legacy_app_install_ad",
            "legacy_responsive_display_ad",
            b"legacy_responsive_display_ad",
            "local_ad",
            b"local_ad",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "responsive_display_ad",
            b"responsive_display_ad",
            "responsive_search_ad",
            b"responsive_search_ad",
            "shopping_comparison_listing_ad",
            b"shopping_comparison_listing_ad",
            "shopping_product_ad",
            b"shopping_product_ad",
            "shopping_smart_ad",
            b"shopping_smart_ad",
            "system_managed_resource_source",
            b"system_managed_resource_source",
            "text_ad",
            b"text_ad",
            "tracking_url_template",
            b"tracking_url_template",
            "type",
            b"type",
            "url_collections",
            b"url_collections",
            "url_custom_parameters",
            b"url_custom_parameters",
            "video_ad",
            b"video_ad",
            "video_responsive_ad",
            b"video_responsive_ad",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_added_by_google_ads", b"_added_by_google_ads"
        ],
    ) -> typing_extensions___Literal["added_by_google_ads"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_display_url", b"_display_url"]
    ) -> typing_extensions___Literal["display_url"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_final_url_suffix", b"_final_url_suffix"
        ],
    ) -> typing_extensions___Literal["final_url_suffix"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_tracking_url_template", b"_tracking_url_template"
        ],
    ) -> typing_extensions___Literal["tracking_url_template"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["ad_data", b"ad_data"]
    ) -> typing_extensions___Literal[
        "text_ad",
        "expanded_text_ad",
        "call_only_ad",
        "expanded_dynamic_search_ad",
        "hotel_ad",
        "shopping_smart_ad",
        "shopping_product_ad",
        "gmail_ad",
        "image_ad",
        "video_ad",
        "video_responsive_ad",
        "responsive_search_ad",
        "legacy_responsive_display_ad",
        "app_ad",
        "legacy_app_install_ad",
        "responsive_display_ad",
        "local_ad",
        "display_upload_ad",
        "app_engagement_ad",
        "shopping_comparison_listing_ad",
    ]: ...

type___Ad = Ad



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlanErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    KeywordPlanErrorValue = typing___NewType("KeywordPlanErrorValue", builtin___int)
    type___KeywordPlanErrorValue = KeywordPlanErrorValue
    KeywordPlanError: _KeywordPlanError
    class _KeywordPlanError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            KeywordPlanErrorEnum.KeywordPlanErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 0)
        UNKNOWN = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 1)
        BID_MULTIPLIER_OUT_OF_RANGE = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 2
        )
        BID_TOO_HIGH = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 3)
        BID_TOO_LOW = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 4)
        BID_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 5
        )
        DAILY_BUDGET_TOO_LOW = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 6
        )
        DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 7
        )
        INVALID_VALUE = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 8)
        KEYWORD_PLAN_HAS_NO_KEYWORDS = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 9
        )
        KEYWORD_PLAN_NOT_ENABLED = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 10
        )
        KEYWORD_PLAN_NOT_FOUND = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 11
        )
        MISSING_BID = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 13)
        MISSING_FORECAST_PERIOD = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 14
        )
        INVALID_FORECAST_DATE_RANGE = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 15
        )
        INVALID_NAME = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 16)
    UNSPECIFIED = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 0)
    UNKNOWN = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 1)
    BID_MULTIPLIER_OUT_OF_RANGE = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 2
    )
    BID_TOO_HIGH = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 3)
    BID_TOO_LOW = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 4)
    BID_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 5
    )
    DAILY_BUDGET_TOO_LOW = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 6)
    DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 7
    )
    INVALID_VALUE = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 8)
    KEYWORD_PLAN_HAS_NO_KEYWORDS = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 9
    )
    KEYWORD_PLAN_NOT_ENABLED = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 10
    )
    KEYWORD_PLAN_NOT_FOUND = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 11
    )
    MISSING_BID = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 13)
    MISSING_FORECAST_PERIOD = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 14
    )
    INVALID_FORECAST_DATE_RANGE = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 15
    )
    INVALID_NAME = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 16)
    type___KeywordPlanError = KeywordPlanError
    def __init__(self,) -> None: ...

type___KeywordPlanErrorEnum = KeywordPlanErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PolicyTopicEvidenceDestinationMismatchUrlTypeEnum(
    google___protobuf___message___Message
):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PolicyTopicEvidenceDestinationMismatchUrlTypeValue = typing___NewType(
        "PolicyTopicEvidenceDestinationMismatchUrlTypeValue", builtin___int
    )
    type___PolicyTopicEvidenceDestinationMismatchUrlTypeValue = (
        PolicyTopicEvidenceDestinationMismatchUrlTypeValue
    )
    PolicyTopicEvidenceDestinationMismatchUrlType: _PolicyTopicEvidenceDestinationMismatchUrlType
    class _PolicyTopicEvidenceDestinationMismatchUrlType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
            0,
        )
        UNKNOWN = typing___cast(
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
            1,
        )
        DISPLAY_URL = typing___cast(
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
            2,
        )
        FINAL_URL = typing___cast(
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
            3,
        )
        FINAL_MOBILE_URL = typing___cast(
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
            4,
        )
        TRACKING_URL = typing___cast(
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
            5,
        )
        MOBILE_TRACKING_URL = typing___cast(
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
            6,
        )
    UNSPECIFIED = typing___cast(
        PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
        0,
    )
    UNKNOWN = typing___cast(
        PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
        1,
    )
    DISPLAY_URL = typing___cast(
        PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
        2,
    )
    FINAL_URL = typing___cast(
        PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
        3,
    )
    FINAL_MOBILE_URL = typing___cast(
        PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
        4,
    )
    TRACKING_URL = typing___cast(
        PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
        5,
    )
    MOBILE_TRACKING_URL = typing___cast(
        PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
        6,
    )
    type___PolicyTopicEvidenceDestinationMismatchUrlType = (
        PolicyTopicEvidenceDestinationMismatchUrlType
    )
    def __init__(self,) -> None: ...

type___PolicyTopicEvidenceDestinationMismatchUrlTypeEnum = (
    PolicyTopicEvidenceDestinationMismatchUrlTypeEnum
)



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UserListErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    UserListErrorValue = typing___NewType("UserListErrorValue", builtin___int)
    type___UserListErrorValue = UserListErrorValue
    UserListError: _UserListError
    class _UserListError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            UserListErrorEnum.UserListErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(UserListErrorEnum.UserListErrorValue, 0)
        UNKNOWN = typing___cast(UserListErrorEnum.UserListErrorValue, 1)
        EXTERNAL_REMARKETING_USER_LIST_MUTATE_NOT_SUPPORTED = typing___cast(
            UserListErrorEnum.UserListErrorValue, 2
        )
        CONCRETE_TYPE_REQUIRED = typing___cast(UserListErrorEnum.UserListErrorValue, 3)
        CONVERSION_TYPE_ID_REQUIRED = typing___cast(
            UserListErrorEnum.UserListErrorValue, 4
        )
        DUPLICATE_CONVERSION_TYPES = typing___cast(
            UserListErrorEnum.UserListErrorValue, 5
        )
        INVALID_CONVERSION_TYPE = typing___cast(UserListErrorEnum.UserListErrorValue, 6)
        INVALID_DESCRIPTION = typing___cast(UserListErrorEnum.UserListErrorValue, 7)
        INVALID_NAME = typing___cast(UserListErrorEnum.UserListErrorValue, 8)
        INVALID_TYPE = typing___cast(UserListErrorEnum.UserListErrorValue, 9)
        CAN_NOT_ADD_LOGICAL_LIST_AS_LOGICAL_LIST_OPERAND = typing___cast(
            UserListErrorEnum.UserListErrorValue, 10
        )
        INVALID_USER_LIST_LOGICAL_RULE_OPERAND = typing___cast(
            UserListErrorEnum.UserListErrorValue, 11
        )
        NAME_ALREADY_USED = typing___cast(UserListErrorEnum.UserListErrorValue, 12)
        NEW_CONVERSION_TYPE_NAME_REQUIRED = typing___cast(
            UserListErrorEnum.UserListErrorValue, 13
        )
        CONVERSION_TYPE_NAME_ALREADY_USED = typing___cast(
            UserListErrorEnum.UserListErrorValue, 14
        )
        OWNERSHIP_REQUIRED_FOR_SET = typing___cast(
            UserListErrorEnum.UserListErrorValue, 15
        )
        USER_LIST_MUTATE_NOT_SUPPORTED = typing___cast(
            UserListErrorEnum.UserListErrorValue, 16
        )
        INVALID_RULE = typing___cast(UserListErrorEnum.UserListErrorValue, 17)
        INVALID_DATE_RANGE = typing___cast(UserListErrorEnum.UserListErrorValue, 27)
        CAN_NOT_MUTATE_SENSITIVE_USERLIST = typing___cast(
            UserListErrorEnum.UserListErrorValue, 28
        )
        MAX_NUM_RULEBASED_USERLISTS = typing___cast(
            UserListErrorEnum.UserListErrorValue, 29
        )
        CANNOT_MODIFY_BILLABLE_RECORD_COUNT = typing___cast(
            UserListErrorEnum.UserListErrorValue, 30
        )
        APP_ID_NOT_SET = typing___cast(UserListErrorEnum.UserListErrorValue, 31)
        USERLIST_NAME_IS_RESERVED_FOR_SYSTEM_LIST = typing___cast(
            UserListErrorEnum.UserListErrorValue, 32
        )
        ADVERTISER_NOT_WHITELISTED_FOR_USING_UPLOADED_DATA = typing___cast(
            UserListErrorEnum.UserListErrorValue, 33
        )
        RULE_TYPE_IS_NOT_SUPPORTED = typing___cast(
            UserListErrorEnum.UserListErrorValue, 34
        )
        CAN_NOT_ADD_A_SIMILAR_USERLIST_AS_LOGICAL_LIST_OPERAND = typing___cast(
            UserListErrorEnum.UserListErrorValue, 35
        )
        CAN_NOT_MIX_CRM_BASED_IN_LOGICAL_LIST_WITH_OTHER_LISTS = typing___cast(
            UserListErrorEnum.UserListErrorValue, 36
        )
    UNSPECIFIED = typing___cast(UserListErrorEnum.UserListErrorValue, 0)
    UNKNOWN = typing___cast(UserListErrorEnum.UserListErrorValue, 1)
    EXTERNAL_REMARKETING_USER_LIST_MUTATE_NOT_SUPPORTED = typing___cast(
        UserListErrorEnum.UserListErrorValue, 2
    )
    CONCRETE_TYPE_REQUIRED = typing___cast(UserListErrorEnum.UserListErrorValue, 3)
    CONVERSION_TYPE_ID_REQUIRED = typing___cast(UserListErrorEnum.UserListErrorValue, 4)
    DUPLICATE_CONVERSION_TYPES = typing___cast(UserListErrorEnum.UserListErrorValue, 5)
    INVALID_CONVERSION_TYPE = typing___cast(UserListErrorEnum.UserListErrorValue, 6)
    INVALID_DESCRIPTION = typing___cast(UserListErrorEnum.UserListErrorValue, 7)
    INVALID_NAME = typing___cast(UserListErrorEnum.UserListErrorValue, 8)
    INVALID_TYPE = typing___cast(UserListErrorEnum.UserListErrorValue, 9)
    CAN_NOT_ADD_LOGICAL_LIST_AS_LOGICAL_LIST_OPERAND = typing___cast(
        UserListErrorEnum.UserListErrorValue, 10
    )
    INVALID_USER_LIST_LOGICAL_RULE_OPERAND = typing___cast(
        UserListErrorEnum.UserListErrorValue, 11
    )
    NAME_ALREADY_USED = typing___cast(UserListErrorEnum.UserListErrorValue, 12)
    NEW_CONVERSION_TYPE_NAME_REQUIRED = typing___cast(
        UserListErrorEnum.UserListErrorValue, 13
    )
    CONVERSION_TYPE_NAME_ALREADY_USED = typing___cast(
        UserListErrorEnum.UserListErrorValue, 14
    )
    OWNERSHIP_REQUIRED_FOR_SET = typing___cast(UserListErrorEnum.UserListErrorValue, 15)
    USER_LIST_MUTATE_NOT_SUPPORTED = typing___cast(
        UserListErrorEnum.UserListErrorValue, 16
    )
    INVALID_RULE = typing___cast(UserListErrorEnum.UserListErrorValue, 17)
    INVALID_DATE_RANGE = typing___cast(UserListErrorEnum.UserListErrorValue, 27)
    CAN_NOT_MUTATE_SENSITIVE_USERLIST = typing___cast(
        UserListErrorEnum.UserListErrorValue, 28
    )
    MAX_NUM_RULEBASED_USERLISTS = typing___cast(
        UserListErrorEnum.UserListErrorValue, 29
    )
    CANNOT_MODIFY_BILLABLE_RECORD_COUNT = typing___cast(
        UserListErrorEnum.UserListErrorValue, 30
    )
    APP_ID_NOT_SET = typing___cast(UserListErrorEnum.UserListErrorValue, 31)
    USERLIST_NAME_IS_RESERVED_FOR_SYSTEM_LIST = typing___cast(
        UserListErrorEnum.UserListErrorValue, 32
    )
    ADVERTISER_NOT_WHITELISTED_FOR_USING_UPLOADED_DATA = typing___cast(
        UserListErrorEnum.UserListErrorValue, 33
    )
    RULE_TYPE_IS_NOT_SUPPORTED = typing___cast(UserListErrorEnum.UserListErrorValue, 34)
    CAN_NOT_ADD_A_SIMILAR_USERLIST_AS_LOGICAL_LIST_OPERAND = typing___cast(
        UserListErrorEnum.UserListErrorValue, 35
    )
    CAN_NOT_MIX_CRM_BASED_IN_LOGICAL_LIST_WITH_OTHER_LISTS = typing___cast(
        UserListErrorEnum.UserListErrorValue, 36
    )
    type___UserListError = UserListError
    def __init__(self,) -> None: ...

type___UserListErrorEnum = UserListErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    NewType as typing___NewType,
    Optional as typing___Optional,
    cast as typing___cast,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.targeting_dimension_pb2 import (
    TargetingDimensionEnum as google___ads___googleads___v5___enums___targeting_dimension_pb2___TargetingDimensionEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class TargetingSetting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def target_restrictions(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___TargetRestriction
    ]: ...
    @property
    def target_restriction_operations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___TargetRestrictionOperation
    ]: ...
    def __init__(
        self,
        *,
        target_restrictions: typing___Optional[
            typing___Iterable[type___TargetRestriction]
        ] = None,
        target_restriction_operations: typing___Optional[
            typing___Iterable[type___TargetRestrictionOperation]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "target_restriction_operations",
            b"target_restriction_operations",
            "target_restrictions",
            b"target_restrictions",
        ],
    ) -> None: ...

type___TargetingSetting = TargetingSetting

class TargetRestriction(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    targeting_dimension: google___ads___googleads___v5___enums___targeting_dimension_pb2___TargetingDimensionEnum.TargetingDimensionValue = ...
    bid_only: builtin___bool = ...
    def __init__(
        self,
        *,
        targeting_dimension: typing___Optional[
            google___ads___googleads___v5___enums___targeting_dimension_pb2___TargetingDimensionEnum.TargetingDimensionValue
        ] = None,
        bid_only: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_bid_only", b"_bid_only", "bid_only", b"bid_only"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_bid_only",
            b"_bid_only",
            "bid_only",
            b"bid_only",
            "targeting_dimension",
            b"targeting_dimension",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_bid_only", b"_bid_only"]
    ) -> typing_extensions___Literal["bid_only"]: ...

type___TargetRestriction = TargetRestriction

class TargetRestrictionOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    OperatorValue = typing___NewType("OperatorValue", builtin___int)
    type___OperatorValue = OperatorValue
    Operator: _Operator
    class _Operator(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            TargetRestrictionOperation.OperatorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(TargetRestrictionOperation.OperatorValue, 0)
        UNKNOWN = typing___cast(TargetRestrictionOperation.OperatorValue, 1)
        ADD = typing___cast(TargetRestrictionOperation.OperatorValue, 2)
        REMOVE = typing___cast(TargetRestrictionOperation.OperatorValue, 3)
    UNSPECIFIED = typing___cast(TargetRestrictionOperation.OperatorValue, 0)
    UNKNOWN = typing___cast(TargetRestrictionOperation.OperatorValue, 1)
    ADD = typing___cast(TargetRestrictionOperation.OperatorValue, 2)
    REMOVE = typing___cast(TargetRestrictionOperation.OperatorValue, 3)
    type___Operator = Operator

    operator: type___TargetRestrictionOperation.OperatorValue = ...
    @property
    def value(self) -> type___TargetRestriction: ...
    def __init__(
        self,
        *,
        operator: typing___Optional[
            type___TargetRestrictionOperation.OperatorValue
        ] = None,
        value: typing___Optional[type___TargetRestriction] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["value", b"value"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "operator", b"operator", "value", b"value"
        ],
    ) -> None: ...

type___TargetRestrictionOperation = TargetRestrictionOperation



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class RecommendationErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    RecommendationErrorValue = typing___NewType(
        "RecommendationErrorValue", builtin___int
    )
    type___RecommendationErrorValue = RecommendationErrorValue
    RecommendationError: _RecommendationError
    class _RecommendationError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            RecommendationErrorEnum.RecommendationErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(RecommendationErrorEnum.RecommendationErrorValue, 0)
        UNKNOWN = typing___cast(RecommendationErrorEnum.RecommendationErrorValue, 1)
        BUDGET_AMOUNT_TOO_SMALL = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 2
        )
        BUDGET_AMOUNT_TOO_LARGE = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 3
        )
        INVALID_BUDGET_AMOUNT = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 4
        )
        POLICY_ERROR = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 5
        )
        INVALID_BID_AMOUNT = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 6
        )
        ADGROUP_KEYWORD_LIMIT = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 7
        )
        RECOMMENDATION_ALREADY_APPLIED = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 8
        )
        RECOMMENDATION_INVALIDATED = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 9
        )
        TOO_MANY_OPERATIONS = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 10
        )
        NO_OPERATIONS = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 11
        )
        DIFFERENT_TYPES_NOT_SUPPORTED = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 12
        )
        DUPLICATE_RESOURCE_NAME = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 13
        )
        RECOMMENDATION_ALREADY_DISMISSED = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 14
        )
        INVALID_APPLY_REQUEST = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 15
        )
    UNSPECIFIED = typing___cast(RecommendationErrorEnum.RecommendationErrorValue, 0)
    UNKNOWN = typing___cast(RecommendationErrorEnum.RecommendationErrorValue, 1)
    BUDGET_AMOUNT_TOO_SMALL = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 2
    )
    BUDGET_AMOUNT_TOO_LARGE = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 3
    )
    INVALID_BUDGET_AMOUNT = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 4
    )
    POLICY_ERROR = typing___cast(RecommendationErrorEnum.RecommendationErrorValue, 5)
    INVALID_BID_AMOUNT = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 6
    )
    ADGROUP_KEYWORD_LIMIT = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 7
    )
    RECOMMENDATION_ALREADY_APPLIED = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 8
    )
    RECOMMENDATION_INVALIDATED = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 9
    )
    TOO_MANY_OPERATIONS = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 10
    )
    NO_OPERATIONS = typing___cast(RecommendationErrorEnum.RecommendationErrorValue, 11)
    DIFFERENT_TYPES_NOT_SUPPORTED = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 12
    )
    DUPLICATE_RESOURCE_NAME = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 13
    )
    RECOMMENDATION_ALREADY_DISMISSED = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 14
    )
    INVALID_APPLY_REQUEST = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 15
    )
    type___RecommendationError = RecommendationError
    def __init__(self,) -> None: ...

type___RecommendationErrorEnum = RecommendationErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlanCampaignErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    KeywordPlanCampaignErrorValue = typing___NewType(
        "KeywordPlanCampaignErrorValue", builtin___int
    )
    type___KeywordPlanCampaignErrorValue = KeywordPlanCampaignErrorValue
    KeywordPlanCampaignError: _KeywordPlanCampaignError
    class _KeywordPlanCampaignError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 0
        )
        UNKNOWN = typing___cast(
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 1
        )
        INVALID_NAME = typing___cast(
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 2
        )
        INVALID_LANGUAGES = typing___cast(
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 3
        )
        INVALID_GEOS = typing___cast(
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 4
        )
        DUPLICATE_NAME = typing___cast(
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 5
        )
        MAX_GEOS_EXCEEDED = typing___cast(
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 6
        )
    UNSPECIFIED = typing___cast(
        KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 0
    )
    UNKNOWN = typing___cast(
        KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 1
    )
    INVALID_NAME = typing___cast(
        KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 2
    )
    INVALID_LANGUAGES = typing___cast(
        KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 3
    )
    INVALID_GEOS = typing___cast(
        KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 4
    )
    DUPLICATE_NAME = typing___cast(
        KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 5
    )
    MAX_GEOS_EXCEEDED = typing___cast(
        KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 6
    )
    type___KeywordPlanCampaignError = KeywordPlanCampaignError
    def __init__(self,) -> None: ...

type___KeywordPlanCampaignErrorEnum = KeywordPlanCampaignErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignExperimentStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignExperimentStatusValue = typing___NewType(
        "CampaignExperimentStatusValue", builtin___int
    )
    type___CampaignExperimentStatusValue = CampaignExperimentStatusValue
    CampaignExperimentStatus: _CampaignExperimentStatus
    class _CampaignExperimentStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 0
        )
        UNKNOWN = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 1
        )
        INITIALIZING = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 2
        )
        INITIALIZATION_FAILED = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 8
        )
        ENABLED = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 3
        )
        GRADUATED = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 4
        )
        REMOVED = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 5
        )
        PROMOTING = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 6
        )
        PROMOTION_FAILED = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 9
        )
        PROMOTED = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 7
        )
        ENDED_MANUALLY = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 10
        )
    UNSPECIFIED = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 0
    )
    UNKNOWN = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 1
    )
    INITIALIZING = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 2
    )
    INITIALIZATION_FAILED = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 8
    )
    ENABLED = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 3
    )
    GRADUATED = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 4
    )
    REMOVED = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 5
    )
    PROMOTING = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 6
    )
    PROMOTION_FAILED = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 9
    )
    PROMOTED = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 7
    )
    ENDED_MANUALLY = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 10
    )
    type___CampaignExperimentStatus = CampaignExperimentStatus
    def __init__(self,) -> None: ...

type___CampaignExperimentStatusEnum = CampaignExperimentStatusEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DateRangeErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    DateRangeErrorValue = typing___NewType("DateRangeErrorValue", builtin___int)
    type___DateRangeErrorValue = DateRangeErrorValue
    DateRangeError: _DateRangeError
    class _DateRangeError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            DateRangeErrorEnum.DateRangeErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 0)
        UNKNOWN = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 1)
        INVALID_DATE = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 2)
        START_DATE_AFTER_END_DATE = typing___cast(
            DateRangeErrorEnum.DateRangeErrorValue, 3
        )
        CANNOT_SET_DATE_TO_PAST = typing___cast(
            DateRangeErrorEnum.DateRangeErrorValue, 4
        )
        AFTER_MAXIMUM_ALLOWABLE_DATE = typing___cast(
            DateRangeErrorEnum.DateRangeErrorValue, 5
        )
        CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = typing___cast(
            DateRangeErrorEnum.DateRangeErrorValue, 6
        )
    UNSPECIFIED = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 0)
    UNKNOWN = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 1)
    INVALID_DATE = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 2)
    START_DATE_AFTER_END_DATE = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 3)
    CANNOT_SET_DATE_TO_PAST = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 4)
    AFTER_MAXIMUM_ALLOWABLE_DATE = typing___cast(
        DateRangeErrorEnum.DateRangeErrorValue, 5
    )
    CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = typing___cast(
        DateRangeErrorEnum.DateRangeErrorValue, 6
    )
    type___DateRangeError = DateRangeError
    def __init__(self,) -> None: ...

type___DateRangeErrorEnum = DateRangeErrorEnum



from typing import Any, Optional

class AccountLinkServiceStub:
    GetAccountLink: Any = ...
    CreateAccountLink: Any = ...
    MutateAccountLink: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AccountLinkServiceServicer:
    def GetAccountLink(self, request: Any, context: Any) -> None: ...
    def CreateAccountLink(self, request: Any, context: Any) -> None: ...
    def MutateAccountLink(self, request: Any, context: Any) -> None: ...

def add_AccountLinkServiceServicer_to_server(servicer: Any, server: Any) -> None: ...

class AccountLinkService:
    @staticmethod
    def GetAccountLink(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def CreateAccountLink(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def MutateAccountLink(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...



from typing import Any, Optional

class CustomerClientServiceStub:
    GetCustomerClient: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CustomerClientServiceServicer:
    def GetCustomerClient(self, request: Any, context: Any) -> None: ...

def add_CustomerClientServiceServicer_to_server(servicer: Any, server: Any) -> None: ...

class CustomerClientService:
    @staticmethod
    def GetCustomerClient(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.enums.month_of_year_pb2 import (
    MonthOfYearEnum as google___ads___googleads___v4___enums___month_of_year_pb2___MonthOfYearEnum,
)
from google.ads.google_ads.v4.proto.resources.invoice_pb2 import (
    Invoice as google___ads___googleads___v4___resources___invoice_pb2___Invoice,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ListInvoicesRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    billing_setup: typing___Text = ...
    issue_year: typing___Text = ...
    issue_month: google___ads___googleads___v4___enums___month_of_year_pb2___MonthOfYearEnum.MonthOfYearValue = ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        billing_setup: typing___Optional[typing___Text] = None,
        issue_year: typing___Optional[typing___Text] = None,
        issue_month: typing___Optional[
            google___ads___googleads___v4___enums___month_of_year_pb2___MonthOfYearEnum.MonthOfYearValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "billing_setup",
            b"billing_setup",
            "customer_id",
            b"customer_id",
            "issue_month",
            b"issue_month",
            "issue_year",
            b"issue_year",
        ],
    ) -> None: ...

type___ListInvoicesRequest = ListInvoicesRequest

class ListInvoicesResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def invoices(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v4___resources___invoice_pb2___Invoice
    ]: ...
    def __init__(
        self,
        *,
        invoices: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v4___resources___invoice_pb2___Invoice
            ]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["invoices", b"invoices"]
    ) -> None: ...

type___ListInvoicesResponse = ListInvoicesResponse



from typing import List, overload

from google.oauth2.credentials import (  # type: ignore
    Credentials as InstalledAppCredentials,
)
from google.oauth2.service_account import (  # type: ignore
    Credentials as ServiceAccountCreds,
)

from google.ads.google_ads.config import (
    _InstalledAppConfigDataRequired,
    _ServiceAccountConfigDataRequired,
)

def get_installed_app_credentials(
    client_id: str, client_secret: str, refresh_token: str, token_uri: str = ...
) -> InstalledAppCredentials: ...
def get_service_account_credentials(
    path_to_private_key_file: str, subject: str, scopes: List[str] = ...
) -> ServiceAccountCreds: ...
@overload
def get_credentials(
    config_data: _InstalledAppConfigDataRequired,
) -> InstalledAppCredentials: ...
@overload
def get_credentials(
    config_data: _ServiceAccountConfigDataRequired,
) -> ServiceAccountCreds: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.distance_bucket_pb2 import (
    DistanceBucketEnum as google___ads___googleads___v5___enums___distance_bucket_pb2___DistanceBucketEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DistanceView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    distance_bucket: google___ads___googleads___v5___enums___distance_bucket_pb2___DistanceBucketEnum.DistanceBucketValue = ...
    metric_system: builtin___bool = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        distance_bucket: typing___Optional[
            google___ads___googleads___v5___enums___distance_bucket_pb2___DistanceBucketEnum.DistanceBucketValue
        ] = None,
        metric_system: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_metric_system", b"_metric_system", "metric_system", b"metric_system"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_metric_system",
            b"_metric_system",
            "distance_bucket",
            b"distance_bucket",
            "metric_system",
            b"metric_system",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_metric_system", b"_metric_system"],
    ) -> typing_extensions___Literal["metric_system"]: ...

type___DistanceView = DistanceView



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CriterionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CriterionTypeValue = typing___NewType("CriterionTypeValue", builtin___int)
    type___CriterionTypeValue = CriterionTypeValue
    CriterionType: _CriterionType
    class _CriterionType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CriterionTypeEnum.CriterionTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(CriterionTypeEnum.CriterionTypeValue, 0)
        UNKNOWN = typing___cast(CriterionTypeEnum.CriterionTypeValue, 1)
        KEYWORD = typing___cast(CriterionTypeEnum.CriterionTypeValue, 2)
        PLACEMENT = typing___cast(CriterionTypeEnum.CriterionTypeValue, 3)
        MOBILE_APP_CATEGORY = typing___cast(CriterionTypeEnum.CriterionTypeValue, 4)
        MOBILE_APPLICATION = typing___cast(CriterionTypeEnum.CriterionTypeValue, 5)
        DEVICE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 6)
        LOCATION = typing___cast(CriterionTypeEnum.CriterionTypeValue, 7)
        LISTING_GROUP = typing___cast(CriterionTypeEnum.CriterionTypeValue, 8)
        AD_SCHEDULE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 9)
        AGE_RANGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 10)
        GENDER = typing___cast(CriterionTypeEnum.CriterionTypeValue, 11)
        INCOME_RANGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 12)
        PARENTAL_STATUS = typing___cast(CriterionTypeEnum.CriterionTypeValue, 13)
        YOUTUBE_VIDEO = typing___cast(CriterionTypeEnum.CriterionTypeValue, 14)
        YOUTUBE_CHANNEL = typing___cast(CriterionTypeEnum.CriterionTypeValue, 15)
        USER_LIST = typing___cast(CriterionTypeEnum.CriterionTypeValue, 16)
        PROXIMITY = typing___cast(CriterionTypeEnum.CriterionTypeValue, 17)
        TOPIC = typing___cast(CriterionTypeEnum.CriterionTypeValue, 18)
        LISTING_SCOPE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 19)
        LANGUAGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 20)
        IP_BLOCK = typing___cast(CriterionTypeEnum.CriterionTypeValue, 21)
        CONTENT_LABEL = typing___cast(CriterionTypeEnum.CriterionTypeValue, 22)
        CARRIER = typing___cast(CriterionTypeEnum.CriterionTypeValue, 23)
        USER_INTEREST = typing___cast(CriterionTypeEnum.CriterionTypeValue, 24)
        WEBPAGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 25)
        OPERATING_SYSTEM_VERSION = typing___cast(
            CriterionTypeEnum.CriterionTypeValue, 26
        )
        APP_PAYMENT_MODEL = typing___cast(CriterionTypeEnum.CriterionTypeValue, 27)
        MOBILE_DEVICE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 28)
        CUSTOM_AFFINITY = typing___cast(CriterionTypeEnum.CriterionTypeValue, 29)
        CUSTOM_INTENT = typing___cast(CriterionTypeEnum.CriterionTypeValue, 30)
        LOCATION_GROUP = typing___cast(CriterionTypeEnum.CriterionTypeValue, 31)
    UNSPECIFIED = typing___cast(CriterionTypeEnum.CriterionTypeValue, 0)
    UNKNOWN = typing___cast(CriterionTypeEnum.CriterionTypeValue, 1)
    KEYWORD = typing___cast(CriterionTypeEnum.CriterionTypeValue, 2)
    PLACEMENT = typing___cast(CriterionTypeEnum.CriterionTypeValue, 3)
    MOBILE_APP_CATEGORY = typing___cast(CriterionTypeEnum.CriterionTypeValue, 4)
    MOBILE_APPLICATION = typing___cast(CriterionTypeEnum.CriterionTypeValue, 5)
    DEVICE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 6)
    LOCATION = typing___cast(CriterionTypeEnum.CriterionTypeValue, 7)
    LISTING_GROUP = typing___cast(CriterionTypeEnum.CriterionTypeValue, 8)
    AD_SCHEDULE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 9)
    AGE_RANGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 10)
    GENDER = typing___cast(CriterionTypeEnum.CriterionTypeValue, 11)
    INCOME_RANGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 12)
    PARENTAL_STATUS = typing___cast(CriterionTypeEnum.CriterionTypeValue, 13)
    YOUTUBE_VIDEO = typing___cast(CriterionTypeEnum.CriterionTypeValue, 14)
    YOUTUBE_CHANNEL = typing___cast(CriterionTypeEnum.CriterionTypeValue, 15)
    USER_LIST = typing___cast(CriterionTypeEnum.CriterionTypeValue, 16)
    PROXIMITY = typing___cast(CriterionTypeEnum.CriterionTypeValue, 17)
    TOPIC = typing___cast(CriterionTypeEnum.CriterionTypeValue, 18)
    LISTING_SCOPE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 19)
    LANGUAGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 20)
    IP_BLOCK = typing___cast(CriterionTypeEnum.CriterionTypeValue, 21)
    CONTENT_LABEL = typing___cast(CriterionTypeEnum.CriterionTypeValue, 22)
    CARRIER = typing___cast(CriterionTypeEnum.CriterionTypeValue, 23)
    USER_INTEREST = typing___cast(CriterionTypeEnum.CriterionTypeValue, 24)
    WEBPAGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 25)
    OPERATING_SYSTEM_VERSION = typing___cast(CriterionTypeEnum.CriterionTypeValue, 26)
    APP_PAYMENT_MODEL = typing___cast(CriterionTypeEnum.CriterionTypeValue, 27)
    MOBILE_DEVICE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 28)
    CUSTOM_AFFINITY = typing___cast(CriterionTypeEnum.CriterionTypeValue, 29)
    CUSTOM_INTENT = typing___cast(CriterionTypeEnum.CriterionTypeValue, 30)
    LOCATION_GROUP = typing___cast(CriterionTypeEnum.CriterionTypeValue, 31)
    type___CriterionType = CriterionType
    def __init__(self,) -> None: ...

type___CriterionTypeEnum = CriterionTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DateRange(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    start_date: typing___Text = ...
    end_date: typing___Text = ...
    def __init__(
        self,
        *,
        start_date: typing___Optional[typing___Text] = None,
        end_date: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_end_date",
            b"_end_date",
            "_start_date",
            b"_start_date",
            "end_date",
            b"end_date",
            "start_date",
            b"start_date",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_end_date",
            b"_end_date",
            "_start_date",
            b"_start_date",
            "end_date",
            b"end_date",
            "start_date",
            b"start_date",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_end_date", b"_end_date"]
    ) -> typing_extensions___Literal["end_date"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_start_date", b"_start_date"]
    ) -> typing_extensions___Literal["start_date"]: ...

type___DateRange = DateRange



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItemSetErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedItemSetErrorValue = typing___NewType("FeedItemSetErrorValue", builtin___int)
    type___FeedItemSetErrorValue = FeedItemSetErrorValue
    FeedItemSetError: _FeedItemSetError
    class _FeedItemSetError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedItemSetErrorEnum.FeedItemSetErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(FeedItemSetErrorEnum.FeedItemSetErrorValue, 0)
        UNKNOWN = typing___cast(FeedItemSetErrorEnum.FeedItemSetErrorValue, 1)
        FEED_ITEM_SET_REMOVED = typing___cast(
            FeedItemSetErrorEnum.FeedItemSetErrorValue, 2
        )
        CANNOT_CLEAR_DYNAMIC_FILTER = typing___cast(
            FeedItemSetErrorEnum.FeedItemSetErrorValue, 3
        )
        CANNOT_CREATE_DYNAMIC_FILTER = typing___cast(
            FeedItemSetErrorEnum.FeedItemSetErrorValue, 4
        )
        INVALID_FEED_TYPE = typing___cast(FeedItemSetErrorEnum.FeedItemSetErrorValue, 5)
        DUPLICATE_NAME = typing___cast(FeedItemSetErrorEnum.FeedItemSetErrorValue, 6)
        WRONG_DYNAMIC_FILTER_FOR_FEED_TYPE = typing___cast(
            FeedItemSetErrorEnum.FeedItemSetErrorValue, 7
        )
    UNSPECIFIED = typing___cast(FeedItemSetErrorEnum.FeedItemSetErrorValue, 0)
    UNKNOWN = typing___cast(FeedItemSetErrorEnum.FeedItemSetErrorValue, 1)
    FEED_ITEM_SET_REMOVED = typing___cast(FeedItemSetErrorEnum.FeedItemSetErrorValue, 2)
    CANNOT_CLEAR_DYNAMIC_FILTER = typing___cast(
        FeedItemSetErrorEnum.FeedItemSetErrorValue, 3
    )
    CANNOT_CREATE_DYNAMIC_FILTER = typing___cast(
        FeedItemSetErrorEnum.FeedItemSetErrorValue, 4
    )
    INVALID_FEED_TYPE = typing___cast(FeedItemSetErrorEnum.FeedItemSetErrorValue, 5)
    DUPLICATE_NAME = typing___cast(FeedItemSetErrorEnum.FeedItemSetErrorValue, 6)
    WRONG_DYNAMIC_FILTER_FOR_FEED_TYPE = typing___cast(
        FeedItemSetErrorEnum.FeedItemSetErrorValue, 7
    )
    type___FeedItemSetError = FeedItemSetError
    def __init__(self,) -> None: ...

type___FeedItemSetErrorEnum = FeedItemSetErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class NotAllowlistedErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    NotAllowlistedErrorValue = typing___NewType(
        "NotAllowlistedErrorValue", builtin___int
    )
    type___NotAllowlistedErrorValue = NotAllowlistedErrorValue
    NotAllowlistedError: _NotAllowlistedError
    class _NotAllowlistedError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            NotAllowlistedErrorEnum.NotAllowlistedErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(NotAllowlistedErrorEnum.NotAllowlistedErrorValue, 0)
        UNKNOWN = typing___cast(NotAllowlistedErrorEnum.NotAllowlistedErrorValue, 1)
        CUSTOMER_NOT_ALLOWLISTED_FOR_THIS_FEATURE = typing___cast(
            NotAllowlistedErrorEnum.NotAllowlistedErrorValue, 2
        )
    UNSPECIFIED = typing___cast(NotAllowlistedErrorEnum.NotAllowlistedErrorValue, 0)
    UNKNOWN = typing___cast(NotAllowlistedErrorEnum.NotAllowlistedErrorValue, 1)
    CUSTOMER_NOT_ALLOWLISTED_FOR_THIS_FEATURE = typing___cast(
        NotAllowlistedErrorEnum.NotAllowlistedErrorValue, 2
    )
    type___NotAllowlistedError = NotAllowlistedError
    def __init__(self,) -> None: ...

type___NotAllowlistedErrorEnum = NotAllowlistedErrorEnum
